{#fullpage_dlg.title}

- {#fullpage_dlg.meta_tab}
- {#fullpage_dlg.appearance_tab}
- {#fullpage_dlg.advanced_tab}

{#fullpage_dlg.meta_props}

{#fullpage_dlg.meta_title} |
{#fullpage_dlg.meta_keywords} |
{#fullpage_dlg.meta_description} |
{#fullpage_dlg.author} |
{#fullpage_dlg.copyright} |
{#fullpage_dlg.meta_robots} |

{#fullpage_dlg.langprops}

{#fullpage_dlg.encoding} |
{#fullpage_dlg.doctypes} |
{#fullpage_dlg.langcode} |
{#fullpage_dlg.langdir} |
{#fullpage_dlg.xml_pi} |

{#fullpage_dlg.appearance_textprops}

{#fullpage_dlg.fontface} |
{#fullpage_dlg.fontsize} |
{#fullpage_dlg.textcolor} |

{#fullpage_dlg.appearance_bgprops}

{#fullpage_dlg.bgimage} |
{#fullpage_dlg.bgcolor} |

{#fullpage_dlg.appearance_marginprops}

{#fullpage_dlg.left_margin} |  | {#fullpage_dlg.right_margin} |
{#fullpage_dlg.top_margin} |  | {#fullpage_dlg.bottom_margin} |

{#fullpage_dlg.appearance_linkprops}

{#fullpage_dlg.link_color} |
| {#fullpage_dlg.visited_color} |
{#fullpage_dlg.active_color} |

{#fullpage_dlg.appearance_style}

{#fullpage_dlg.stylesheet} |
{#fullpage_dlg.style} |

{#fullpage_dlg.add_title}
{#fullpage_dlg.add_meta}
{#fullpage_dlg.add_script}
{#fullpage_dlg.add_style}
{#fullpage_dlg.add_link}
{#fullpage_dlg.add_base}
{#fullpage_dlg.add_comment}

{#fullpage_dlg.head_elements}
{#fullpage_dlg.meta_element}

{#fullpage_dlg.type} |
{#fullpage_dlg.name} |
{#fullpage_dlg.content} |

{#fullpage_dlg.title_element}

{#fullpage_dlg.meta_title} |

{#fullpage_dlg.script_element}

- {#fullpage_dlg.properties}
- {#fullpage_dlg.value}

{#fullpage_dlg.type} |
{#fullpage_dlg.src} |
{#fullpage_dlg.charset} |
{#fullpage_dlg.defer} |

{#fullpage_dlg.style_element}

- {#fullpage_dlg.properties}
- {#fullpage_dlg.value}

{#fullpage_dlg.type} |
{#fullpage_dlg.media} |

{#fullpage_dlg.base_element}

{#fullpage_dlg.href} |
{#fullpage_dlg.target} |

{#fullpage_dlg.link_element}

- {#fullpage_dlg.general_props}
- {#fullpage_dlg.advanced_props}

{#fullpage_dlg.href} |
{#fullpage_dlg.meta_title} |
{#fullpage_dlg.type} |
{#fullpage_dlg.media} |
{#fullpage_dlg.rel} |

{#fullpage_dlg.charset} |
{#fullpage_dlg.hreflang} |
{#fullpage_dlg.target} |
{#fullpage_dlg.rev} |

{#fullpage_dlg.comment_element}